@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Data::Dumper;
 use DBI;
-use Helios::Worker;
+use Helios::Service;
 
 our $VERSION = '1.40';
 our $dbh;
@@ -17,8 +17,8 @@ if (defined($ENV{HELIOS_INI}) ) {
 } else {
     $inifile = './helios.ini';
 }
-my $worker = new Helios::Worker;
-%config = $worker->getParamsFromIni($inifile);
+my $worker = new Helios::Service;
+%config = $worker->getConfigFromIni($inifile);
 
 $dbh = DBI->connect($config{dsn}, $config{user}, $config{password});
 
@@ -339,16 +339,16 @@ __END__
 
 =head1 SEE ALSO
 
-L<Helios::Panoptes>, L<Helios::Worker>, L<helios.pl>, <CGI::Application>, L<HTML::Template>
+L<Helios::Panoptes>, L<Helios::Service>, L<helios.pl>, <CGI::Application>, L<HTML::Template>
 
 =head1 AUTHOR 
 
-Andrew Johnson, <ajohnson at ittoolbox dotcom>
-Ben Kucenski, <bkucenski at ittoolbox dotcom>
+Andrew Johnson, <lajandy at cpan dotorg>
+Ben Kucenski, <bkucenski at toolbox dotcom>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008 by CEB Toolbox, Inc.
+Copyright (C) 2008-9 by CEB Toolbox, Inc.
 
 This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself, either Perl version 5.8.0 or, at your option, any later version of Perl 5 you may have available.
 
